@@ -275,7 +275,7 @@ if ($ret === FALSE) {
 }
 
 $dispusr = $web_conf[$url_data['script']]['displayuser'];
-$dispusr = htmlspecialchars($ldapdata[0][$dispusr][0]);
+$dispusr = escape_html($ldapdata[0][$dispusr][0]);
 
 $mode = MODE_LDAPDATA;
 if (isset($_POST['modify'])) {
